package SparkX::Form::BasicValidators;
our $VERSION = '0.2102';


# ABSTRACT: A selection of validators to make writing custom fields easier.

use warnings;
use strict;

1;



=pod

=head1 NAME

SparkX::Form::BasicValidators - A selection of validators to make writing custom fields easier.

=head1 VERSION

version 0.2102

=head1 SEE ALSO

=over 4

=item L<Spark::Form> - The forms module that started it all

=item L<Spark::Form::Manual> - Walk-through

=back 



=head1 AUTHOR

  James Laver L<http://jameslaver.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2009 by James Laver C<< <sprintf qw(%s@%s.%s cpan jameslaver com)> >>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut 



__END__

